#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-contrib
version:              0.5.1
visibility:           public
id:                   hspec-contrib-0.5.1-LsHqY1RviOE3doenRvvPyO
key:                  hspec-contrib-0.5.1-LsHqY1RviOE3doenRvvPyO
license:              MIT
copyright:
    (c) 2011-2018 Simon Hengel,
    (c) 2014 Junji Hashimoto

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             http://hspec.github.io/
synopsis:             Contributed functionality for Hspec
description:          Contributed functionality for Hspec
category:             Testing
abi:                  b6aebd1502b80058859370cf8ed612a4
exposed:              True
exposed-modules:      Test.Hspec.Contrib.HUnit Test.Hspec.Contrib.Retry
import-dirs:          /usr/lib/ghc-8.10.5/site-local/hspec-contrib-0.5.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/hspec-contrib-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/hspec-contrib-0.5.1
hs-libraries:         HShspec-contrib-0.5.1-LsHqY1RviOE3doenRvvPyO
depends:
    HUnit-1.6.2.0-8FsjWfKzSV74wDnwnuEJe4 base-4.14.2.0
    hspec-core-2.8.2-KLUu39SDCkuHXBcAtSZ1N9

haddock-interfaces:
    /usr/share/doc/haskell-hspec-contrib/html/hspec-contrib.haddock

haddock-html:         /usr/share/doc/haskell-hspec-contrib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

